@@ -27,7 +27,7 @@ TESTING_RECEIVERS = {"AVR-X4100W": NO_ZONES, "AVR-2312CI": NO_ZONES,
                      "SR5008": NO_ZONES, "M-CR603": NO_ZONES,
                      "NR1604": ZONE2_ZONE3, "AVR-4810": NO_ZONES,
                      "AVR-3312": NO_ZONES, "NR1609": ZONE2,
-                     "AVC-8500H": ZONE2_ZONE3}
+                     "AVC-8500H": ZONE2_ZONE3, "AVR-X4300H": ZONE2_ZONE3}
 
 APPCOMMAND_URL = "/goform/AppCommand.xml"
 STATUS_URL = "/goform/formMainZone_MainZoneXmlStatus.xml"
@@ -133,8 +133,6 @@ class TestMainFunctions(testtools.TestCase):
             self.denon = denonavr.DenonAVR(FAKE_IP, add_zones=zones)
             # Switch through all functions and check if successful
             for zone in self.denon.zones.values():
-                if receiver == 'AVC-8500H':
-                    print(receiver, zone.input_func_list)
                 for input_func in zone.input_func_list:
                     self.denon.set_input_func(input_func)
                     self.assertEqual(
